//LabPlot : ExplorerDialog.h

#ifndef EXPLORERDIALOG_H
#define EXPLORERDIALOG_H

#include <qfont.h>
#include <qcheckbox.h>
#include <qpopupmenu.h>
#include "Worksheet.h"
#include "Dialog.h"

class ExplorerDialog: public Dialog
{
	Q_OBJECT
public:
	ExplorerDialog(MainWin *mw, const char *name);
private slots:
	void initlist();
	void rmouse(QListViewItem *item, const QPoint & point, int );
private:
	QListView *lv;
	QPopupMenu *menu;
};

#endif //EXPLORERDIALOG_H
